@@ -459,6 +459,8 @@ def search(
                     "riskSeverity",
                 ]
 
+    flatten = format in (OutputFormat.TABLE, OutputFormat.CSV)
+
     if use_checkpoint:
         cursor = _get_file_event_cursor_store(state.profile.name)
         checkpoint = _handle_timestamp_checkpoint(cursor.get(use_checkpoint), state)
@@ -466,7 +468,8 @@ def search(
         if state.profile.use_v2_file_events == "True":
 
             def checkpoint_func(event):
-                cursor.replace(use_checkpoint, event["event.id"])
+                event_id = event["event.id"] if flatten else event["event"]["id"]
+                cursor.replace(use_checkpoint, event_id)
 
         else:
 
@@ -477,7 +480,6 @@ def search(
         checkpoint = checkpoint_func = None
 
     query = _construct_query(state, begin, end, saved_search, advanced_query, or_query)
-    flatten = format in (OutputFormat.TABLE, OutputFormat.CSV)
     dfs = _get_all_file_events(state, query, checkpoint, flatten)
     formatter = FileEventsOutputFormatter(format, checkpoint_func=checkpoint_func)
     # sending to pager when checkpointing can be inaccurate due to pager buffering, so disallow pager
