@@ -1,33 +1,32 @@
 import os
-
 from configparser import ConfigParser
 
 import code42cli.util as util
-from code42cli.compat import str
-from code42cli.logger import get_main_cli_logger
 
 
 class NoConfigProfileError(Exception):
     def __init__(self, profile_arg_name=None):
         message = (
-            u"Profile '{}' does not exist.".format(profile_arg_name)
+            f"Profile '{profile_arg_name}' does not exist."
             if profile_arg_name
-            else u"Profile does not exist."
+            else "Profile does not exist."
         )
-        super(NoConfigProfileError, self).__init__(message)
+        super().__init__(message)
 
 
-class ConfigAccessor(object):
-    DEFAULT_VALUE = u"__DEFAULT__"
-    AUTHORITY_KEY = u"c42_authority_url"
-    USERNAME_KEY = u"c42_username"
-    IGNORE_SSL_ERRORS_KEY = u"ignore-ssl-errors"
-    DEFAULT_PROFILE = u"default_profile"
-    _INTERNAL_SECTION = u"Internal"
+class ConfigAccessor:
+    DEFAULT_VALUE = "__DEFAULT__"
+    AUTHORITY_KEY = "c42_authority_url"
+    USERNAME_KEY = "c42_username"
+    IGNORE_SSL_ERRORS_KEY = "ignore-ssl-errors"
+    USE_V2_FILE_EVENTS_KEY = "use-v2-file-events"
+    API_CLIENT_AUTH_KEY = "api-client-auth"
+    DEFAULT_PROFILE = "default_profile"
+    _INTERNAL_SECTION = "Internal"
 
     def __init__(self, parser):
         self.parser = parser
-        file_name = u"config.cfg"
+        file_name = "config.cfg"
         self.path = os.path.join(util.get_user_project_path(), file_name)
         if not os.path.exists(self.path):
             self._create_internal_section()
@@ -41,10 +40,10 @@ class ConfigAccessor(object):
         If the name does not exist or there is no existing profile, it will throw an exception.
         """
         name = name or self._default_profile_name
-        if name not in self._get_sections() or name == self.DEFAULT_VALUE:
+        if name not in self.parser.sections() or name == self.DEFAULT_VALUE:
             name = name if name != self.DEFAULT_VALUE else None
             raise NoConfigProfileError(name)
-        return self._get_profile(name)
+        return self.parser[name]
 
     def get_all_profiles(self):
         """Returns all the available profiles."""
@@ -54,7 +53,15 @@ class ConfigAccessor(object):
             profiles.append(self.get_profile(name))
         return profiles
 
-    def create_profile(self, name, server, username, ignore_ssl_errors):
+    def create_profile(
+        self,
+        name,
+        server,
+        username,
+        ignore_ssl_errors,
+        use_v2_file_events,
+        api_client_auth,
+    ):
         """Creates a new profile if one does not already exist for that name."""
         try:
             self.get_profile(name)
@@ -65,17 +72,36 @@ class ConfigAccessor(object):
                 raise ex
 
         profile = self.get_profile(name)
-        self.update_profile(profile.name, server, username, ignore_ssl_errors)
+        self.update_profile(
+            profile.name,
+            server,
+            username,
+            ignore_ssl_errors,
+            use_v2_file_events,
+            api_client_auth,
+        )
         self._try_complete_setup(profile)
 
-    def update_profile(self, name, server=None, username=None, ignore_ssl_errors=None):
+    def update_profile(
+        self,
+        name,
+        server=None,
+        username=None,
+        ignore_ssl_errors=None,
+        use_v2_file_events=None,
+        api_client_auth=None,
+    ):
         profile = self.get_profile(name)
         if server:
-            self._set_authority_url(server, profile)
+            profile[self.AUTHORITY_KEY] = server.strip()
         if username:
-            self._set_username(username, profile)
+            profile[self.USERNAME_KEY] = username.strip()
         if ignore_ssl_errors is not None:
-            self._set_ignore_ssl_errors(ignore_ssl_errors, profile)
+            profile[self.IGNORE_SSL_ERRORS_KEY] = str(ignore_ssl_errors)
+        if use_v2_file_events is not None:
+            profile[self.USE_V2_FILE_EVENTS_KEY] = str(use_v2_file_events)
+        if api_client_auth is not None:
+            profile[self.API_CLIENT_AUTH_KEY] = str(api_client_auth)
         self._save()
 
     def switch_default_profile(self, new_default_name):
@@ -84,9 +110,6 @@ class ConfigAccessor(object):
             raise NoConfigProfileError(new_default_name)
         self._internal[self.DEFAULT_PROFILE] = new_default_name
         self._save()
-        get_main_cli_logger().print_info(
-            u"{} has been set as the default profile.".format(new_default_name)
-        )
 
     def delete_profile(self, name):
         """Deletes a profile."""
@@ -97,21 +120,6 @@ class ConfigAccessor(object):
             self._internal[self.DEFAULT_PROFILE] = self.DEFAULT_VALUE
         self._save()
 
-    def _set_authority_url(self, new_value, profile):
-        profile[self.AUTHORITY_KEY] = new_value.strip()
-
-    def _set_username(self, new_value, profile):
-        profile[self.USERNAME_KEY] = new_value.strip()
-
-    def _set_ignore_ssl_errors(self, new_value, profile):
-        profile[self.IGNORE_SSL_ERRORS_KEY] = str(new_value)
-
-    def _get_sections(self):
-        return self.parser.sections()
-
-    def _get_profile(self, name):
-        return self.parser[name]
-
     @property
     def _internal(self):
         return self.parser[self._INTERNAL_SECTION]
@@ -121,7 +129,7 @@ class ConfigAccessor(object):
         return self._internal[self.DEFAULT_PROFILE]
 
     def _get_profile_names(self):
-        names = list(self._get_sections())
+        names = list(self.parser.sections())
         names.remove(self._INTERNAL_SECTION)
         return names
 
@@ -136,9 +144,12 @@ class ConfigAccessor(object):
         self.parser[name][self.AUTHORITY_KEY] = self.DEFAULT_VALUE
         self.parser[name][self.USERNAME_KEY] = self.DEFAULT_VALUE
         self.parser[name][self.IGNORE_SSL_ERRORS_KEY] = str(False)
+        self.parser[name][self.USE_V2_FILE_EVENTS_KEY] = str(False)
+        self.parser[name][self.API_CLIENT_AUTH_KEY] = str(False)
 
     def _save(self):
-        util.open_file(self.path, u"w+", lambda file: self.parser.write(file))
+        with open(self.path, "w+", encoding="utf-8") as file:
+            self.parser.write(file)
 
     def _try_complete_setup(self, profile):
         authority = profile.get(self.AUTHORITY_KEY)
@@ -151,7 +162,6 @@ class ConfigAccessor(object):
             return
 
         self._save()
-        get_main_cli_logger().print_info(u"Successfully saved profile '{}'.".format(profile.name))
 
         default_profile = self._internal.get(self.DEFAULT_PROFILE)
         if default_profile is None or default_profile == self.DEFAULT_VALUE:
